@@ -3,17 +3,17 @@
 /* The name of this package (not localized) */
 const PACKAGE_NAME = 'gnome-shell';
 /* The version of this package */
-const PACKAGE_VERSION = '3.4.1';
+const PACKAGE_VERSION = '3.4.2';
 /* The version of GJS we're linking to */
-const GJS_VERSION = '1.32.0';
+const GJS_VERSION = '1.33.3';
 /* 1 if gnome-bluetooth is available, 0 otherwise */
 const HAVE_BLUETOOTH = 1;
 /* The system TLS CA list */
-const SHELL_SYSTEM_CA_FILE = '/etc/pki/tls/certs/ca-bundle.crt';
+const SHELL_SYSTEM_CA_FILE = '/etc/ssl/certs/ca-certificates.crt';
 /* gettext package */
 const GETTEXT_PACKAGE = 'gnome-shell';
 /* locale dir */
-const LOCALEDIR = '/home/otaylor/gnome/install/share/locale';
+const LOCALEDIR = '/home/florian/opt/gnome/share/locale';
 /* other standard directories */
-const LIBEXECDIR = '/home/otaylor/gnome/install/libexec';
-const SYSCONFDIR = '/home/otaylor/gnome/install/etc';
+const LIBEXECDIR = '/home/florian/opt/gnome/libexec';
+const SYSCONFDIR = '/home/florian/opt/gnome/etc';
