@@ -1,3 +1,5 @@
+// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
+
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 
@@ -36,7 +38,7 @@ function recursivelyDeleteDir(dir) {
         let child = dir.get_child(info.get_name());
         if (type == Gio.FileType.REGULAR)
             deleteGFile(child);
-        else if (type == Gio.TypeType.DIRECTORY)
+        else if (type == Gio.FileType.DIRECTORY)
             recursivelyDeleteDir(child);
     }
 
