@@ -10,6 +10,7 @@ const Pango = imports.gi.Pango;
 const St = imports.gi.St;
 const Shell = imports.gi.Shell;
 const Signals = imports.signals;
+const Atk = imports.gi.Atk;
 
 const Params = imports.misc.params;
 
@@ -40,9 +41,10 @@ const ModalDialog = new Lang.Class({
         this._hasModal = false;
         this._shellReactive = params.shellReactive;
 
-        this._group = new St.Group({ visible: false,
-                                     x: 0,
-                                     y: 0 });
+        this._group = new St.Widget({ visible: false,
+                                      x: 0,
+                                      y: 0,
+                                      accessible_role: Atk.Role.DIALOG });
         Main.uiGroup.add_actor(this._group);
 
         let constraint = new Clutter.BindConstraint({ source: global.stage,
@@ -87,6 +89,7 @@ const ModalDialog = new Lang.Class({
                                  y_align: St.Align.START });
 
         this._buttonLayout = new St.BoxLayout({ style_class: 'modal-dialog-button-box',
+                                                visible:     false,
                                                 vertical:    false });
         this._dialogLayout.add(this._buttonLayout,
                                { expand:  true,
@@ -95,6 +98,7 @@ const ModalDialog = new Lang.Class({
 
         global.focus_manager.add_group(this._dialogLayout);
         this._initialKeyFocus = this._dialogLayout;
+        this._initialKeyFocusDestroyId = 0;
         this._savedKeyFocus = null;
     },
 
@@ -108,6 +112,8 @@ const ModalDialog = new Lang.Class({
         this._buttonLayout.destroy_all_children();
         this._actionKeys = {};
 
+        this._buttonLayout.visible = (buttons.length > 0);
+
         for (let i = 0; i < buttons.length; i++) {
             let buttonInfo = buttons[i];
             let label = buttonInfo['label'];
@@ -129,8 +135,7 @@ const ModalDialog = new Lang.Class({
             else
                 x_alignment = St.Align.MIDDLE;
 
-            if (this._initialKeyFocus == this._dialogLayout ||
-                this._buttonLayout.contains(this._initialKeyFocus))
+            if (!this._initialKeyFocusDestroyId)
                 this._initialKeyFocus = buttonInfo.button;
             this._buttonLayout.add(buttonInfo.button,
                                    { expand: true,
@@ -200,7 +205,15 @@ const ModalDialog = new Lang.Class({
     },
 
     setInitialKeyFocus: function(actor) {
+        if (this._initialKeyFocusDestroyId)
+            this._initialKeyFocus.disconnect(this._initialKeyFocusDestroyId);
+
         this._initialKeyFocus = actor;
+
+        this._initialKeyFocusDestroyId = actor.connect('destroy', Lang.bind(this, function() {
+            this._initialKeyFocus = this._dialogLayout;
+            this._initialKeyFocusDestroyId = 0;
+        }));
     },
 
     open: function(timestamp) {
