@@ -531,7 +531,8 @@ const VPNRequestHandler = new Lang.Class({
         let contentOverride;
 
         try {
-            keyfile.load_from_data(this._dataStdout.peek_buffer(), -1,
+            let data = this._dataStdout.peek_buffer();
+            keyfile.load_from_data(data.toString(), data.length,
                                    GLib.KeyFileFlags.NONE);
 
             if (keyfile.get_integer(VPN_UI_GROUP, 'Version') != 2)
