@@ -221,12 +221,19 @@ const NotificationDaemon = new Lang.Class({
         let [appName, replacesId, icon, summary, body, actions, hints, timeout] = params;
         let id;
 
+        for (let hint in hints) {
+            // unpack the variants
+            hints[hint] = hints[hint].deep_unpack();
+        }
+
+        hints = Params.parse(hints, { urgency: Urgency.NORMAL }, true);
+
         // Filter out chat, presence, calls and invitation notifications from
         // Empathy, since we handle that information from telepathyClient.js
         if (appName == 'Empathy' && (hints['category'] == 'im.received' ||
               hints['category'] == 'x-empathy.im.room-invitation' ||
               hints['category'] == 'x-empathy.call.incoming' ||
-              hints['category'] == 'x-empathy.call.incoming"' ||
+              hints['category'] == 'x-empathy.transfer.incoming' ||
               hints['category'] == 'x-empathy.im.subscription-request' ||
               hints['category'] == 'presence.online' ||
               hints['category'] == 'presence.offline')) {
@@ -249,13 +256,6 @@ const NotificationDaemon = new Lang.Class({
             }
         }
 
-        for (let hint in hints) {
-            // unpack the variants
-            hints[hint] = hints[hint].deep_unpack();
-        }
-
-        hints = Params.parse(hints, { urgency: Urgency.NORMAL }, true);
-
         // Be compatible with the various hints for image data and image path
         // 'image-data' and 'image-path' are the latest name of these hints, introduced in 1.2
 
