@@ -6,6 +6,7 @@ const Lang = imports.lang;
 const Shell = imports.gi.Shell;
 const Signals = imports.signals;
 const St = imports.gi.St;
+const Atk = imports.gi.Atk;
 
 const Main = imports.ui.main;
 const Params = imports.misc.params;
@@ -99,7 +100,8 @@ const Button = new Lang.Class({
     _init: function(menuAlignment, nameText, dontCreateMenu) {
         this.parent({ reactive: true,
                       can_focus: true,
-                      track_hover: true });
+                      track_hover: true,
+                      accessible_role: Atk.Role.MENU });
 
         this.actor.connect('button-press-event', Lang.bind(this, this._onButtonPress));
         this.actor.connect('key-press-event', Lang.bind(this, this._onSourceKeyPress));
@@ -147,15 +149,6 @@ const Button = new Lang.Class({
         if (!this.menu)
             return;
 
-        if (!this.menu.isOpen) {
-            // Setting the max-height won't do any good if the minimum height of the
-            // menu is higher then the screen; it's useful if part of the menu is
-            // scrollable so the minimum height is smaller than the natural height
-            let monitor = Main.layoutManager.primaryMonitor;
-            this.menu.actor.style = ('max-height: ' +
-                                     Math.round(monitor.height - Main.panel.actor.height) +
-                                     'px;');
-        }
         this.menu.toggle();
     },
 
@@ -198,6 +191,14 @@ const Button = new Lang.Class({
             this.actor.add_style_pseudo_class('active');
         else
             this.actor.remove_style_pseudo_class('active');
+
+        // Setting the max-height won't do any good if the minimum height of the
+        // menu is higher then the screen; it's useful if part of the menu is
+        // scrollable so the minimum height is smaller than the natural height
+        let monitor = Main.layoutManager.primaryMonitor;
+        this.menu.actor.style = ('max-height: ' +
+                                 Math.round(monitor.height - Main.panel.actor.height) +
+                                 'px;');
     },
 
     destroy: function() {
