@@ -17,6 +17,7 @@ const XdndHandler = new Lang.Class({
         // Used as a drag actor in case we don't have a cursor window clone
         this._dummy = new Clutter.Rectangle({ width: 1, height: 1, opacity: 0 });
         global.stage.add_actor(this._dummy);
+        Shell.util_set_hidden_from_pick(this._dummy, true);
         this._dummy.hide();
 
         // Mutter delays the creation of the output window as long
@@ -112,10 +113,11 @@ const XdndHandler = new Lang.Class({
 
         while (pickedActor) {
                 if (pickedActor._delegate && pickedActor._delegate.handleDragOver) {
+                    let [r, targX, targY] = pickedActor.transform_stage_point(x, y);
                     let result = pickedActor._delegate.handleDragOver(this,
                                                                       dragEvent.dragActor,
-                                                                      x,
-                                                                      y,
+                                                                      targX,
+                                                                      targY,
                                                                       global.get_current_time());
                     if (result != DND.DragMotionResult.CONTINUE)
                         return;
