@@ -245,9 +245,9 @@ st_icon_allocate (ClutterActor           *actor,
        * of doing this is that it may not be obvious that they have to turn off
        * fill to align the icon non-centered in the parent container.
        *
-       * We don't use _st_allocate_fill() for a bit of efficiency and because we
-       * expect to get rid of the child actor in favor of a CoglTexture in the
-       * future.
+       * We don't use clutter_actor_allocate_align_fill() for a bit of efficiency
+       * and because we expect to get rid of the child actor in favor of a
+       * CoglTexture in the future.
        */
       content_box.x1 = (int)(0.5 + content_box.x1 + (content_box.x2 - content_box.x1 - priv->icon_size) / 2.);
       content_box.x2 = content_box.x1 + priv->icon_size;
@@ -481,9 +481,7 @@ st_icon_update (StIcon *icon)
   if (priv->gicon)
     {
       priv->pending_texture = st_texture_cache_load_gicon (cache,
-                                                           (priv->icon_type != ST_ICON_APPLICATION &&
-                                                            priv->icon_type != ST_ICON_DOCUMENT) ?
-                                                           theme_node : NULL,
+                                                           theme_node,
                                                            priv->gicon,
                                                            priv->icon_size);
     }
