@@ -96,7 +96,7 @@ struct _StScrollViewPrivate
   gfloat        row_size;
   gfloat        column_size;
 
-  StScrollViewFade *vfade_effect;
+  StScrollViewFade *fade_effect;
 
   gboolean      row_size_set : 1;
   gboolean      column_size_set : 1;
@@ -154,38 +154,43 @@ st_scroll_view_get_property (GObject    *object,
 }
 
 /**
- * st_scroll_view_update_vfade_effect:
+ * st_scroll_view_update_fade_effect:
  * @self: a #StScrollView
- * @fade_offset: The length of the fade effect, in pixels.
+ * @vfade_offset: The length of the veritcal fade effect, in pixels.
+ * @hfade_offset: The length of the horizontal fade effect, in pixels.
  *
  * Sets the height of the fade area area in pixels. A value of 0
  * disables the effect.
  */
 static void
-st_scroll_view_update_vfade_effect (StScrollView *self,
-                                    float fade_offset)
+st_scroll_view_update_fade_effect (StScrollView *self,
+                                   float vfade_offset,
+                                   float hfade_offset)
 {
   StScrollViewPrivate *priv = ST_SCROLL_VIEW (self)->priv;
 
   /* A fade amount of more than 0 enables the effect. */
-  if (fade_offset > 0.)
+  if (vfade_offset > 0. || hfade_offset > 0.)
     {
-      if (priv->vfade_effect == NULL) {
-        priv->vfade_effect = g_object_new (ST_TYPE_SCROLL_VIEW_FADE, NULL);
+      if (priv->fade_effect == NULL) {
+        priv->fade_effect = g_object_new (ST_TYPE_SCROLL_VIEW_FADE, NULL);
 
-        clutter_actor_add_effect_with_name (CLUTTER_ACTOR (self), "vfade",
-                                            CLUTTER_EFFECT (priv->vfade_effect));
+        clutter_actor_add_effect_with_name (CLUTTER_ACTOR (self), "fade",
+                                            CLUTTER_EFFECT (priv->fade_effect));
       }
 
-      g_object_set (priv->vfade_effect,
-                    "fade-offset", fade_offset,
+      g_object_set (priv->fade_effect,
+                    "vfade-offset", vfade_offset,
+                    NULL);
+      g_object_set (priv->fade_effect,
+                    "hfade-offset", hfade_offset,
                     NULL);
     }
    else
     {
-      if (priv->vfade_effect != NULL) {
-        clutter_actor_remove_effect (CLUTTER_ACTOR (self), CLUTTER_EFFECT (priv->vfade_effect));
-        priv->vfade_effect = NULL;
+      if (priv->fade_effect != NULL) {
+        clutter_actor_remove_effect (CLUTTER_ACTOR (self), CLUTTER_EFFECT (priv->fade_effect));
+        priv->fade_effect = NULL;
       }
     }
 
@@ -227,10 +232,10 @@ st_scroll_view_dispose (GObject *object)
 {
   StScrollViewPrivate *priv = ST_SCROLL_VIEW (object)->priv;
 
-  if (priv->vfade_effect)
+  if (priv->fade_effect)
     {
-      clutter_actor_remove_effect (CLUTTER_ACTOR (object), CLUTTER_EFFECT (priv->vfade_effect));
-      priv->vfade_effect = NULL;
+      clutter_actor_remove_effect (CLUTTER_ACTOR (object), CLUTTER_EFFECT (priv->fade_effect));
+      priv->fade_effect = NULL;
     }
 
   if (priv->vscroll)
@@ -382,7 +387,6 @@ st_scroll_view_get_preferred_width (ClutterActor *actor,
       break;
     }
 
-  account_for_vscrollbar = priv->vscrollbar_policy != GTK_POLICY_NEVER;
   if (account_for_vscrollbar)
     {
       float sb_width = get_scrollbar_width (ST_SCROLL_VIEW (actor), for_height);
@@ -583,7 +587,7 @@ st_scroll_view_allocate (ClutterActor          *actor,
   /* Vertical scrollbar */
   if (CLUTTER_ACTOR_IS_VISIBLE (priv->vscroll))
     {
-      if (st_widget_get_direction (ST_WIDGET (actor)) == ST_TEXT_DIRECTION_RTL)
+      if (clutter_actor_get_text_direction (actor) == CLUTTER_TEXT_DIRECTION_RTL)
         {
           child_box.x1 = content_box.x1;
           child_box.x2 = content_box.x1 + sb_width;
@@ -602,7 +606,7 @@ st_scroll_view_allocate (ClutterActor          *actor,
   /* Horizontal scrollbar */
   if (CLUTTER_ACTOR_IS_VISIBLE (priv->hscroll))
     {
-      if (st_widget_get_direction (ST_WIDGET (actor)) == ST_TEXT_DIRECTION_RTL)
+      if (clutter_actor_get_text_direction (actor) == CLUTTER_TEXT_DIRECTION_RTL)
         {
           child_box.x1 = content_box.x1 + (vscrollbar_visible ? sb_width : 0);
           child_box.x2 = content_box.x2;
@@ -627,7 +631,7 @@ st_scroll_view_allocate (ClutterActor          *actor,
     sb_width = 0;
 
   /* Child */
-  if (st_widget_get_direction (ST_WIDGET (actor)) == ST_TEXT_DIRECTION_RTL)
+  if (clutter_actor_get_text_direction (actor) == CLUTTER_TEXT_DIRECTION_RTL)
     {
       child_box.x1 = content_box.x1 + sb_width;
       child_box.x2 = content_box.x2;
@@ -668,8 +672,9 @@ st_scroll_view_style_changed (StWidget *widget)
   StScrollViewPrivate *priv = self->priv;
 
   StThemeNode *theme_node = st_widget_get_theme_node (widget);
-  gdouble fade_offset = st_theme_node_get_length (theme_node, "-st-vfade-offset");
-  st_scroll_view_update_vfade_effect (self, fade_offset);
+  gdouble vfade_offset = st_theme_node_get_length (theme_node, "-st-vfade-offset");
+  gdouble hfade_offset = st_theme_node_get_length (theme_node, "-st-hfade-offset");
+  st_scroll_view_update_fade_effect (self, vfade_offset, hfade_offset);
 
   st_widget_style_changed (ST_WIDGET (priv->hscroll));
   st_widget_style_changed (ST_WIDGET (priv->vscroll));
@@ -682,7 +687,7 @@ st_scroll_view_scroll_event (ClutterActor       *self,
                              ClutterScrollEvent *event)
 {
   StScrollViewPrivate *priv = ST_SCROLL_VIEW (self)->priv;
-  gdouble lower, value, upper, step;
+  gdouble lower, value, upper, step, hvalue, vvalue, delta_x, delta_y;
 
   /* don't handle scroll events if requested not to */
   if (!priv->mouse_scroll)
@@ -690,6 +695,16 @@ st_scroll_view_scroll_event (ClutterActor       *self,
 
   switch (event->direction)
     {
+    case CLUTTER_SCROLL_SMOOTH:
+      clutter_event_get_scroll_delta ((ClutterEvent *)event,
+                                      &delta_x, &delta_y);
+      g_object_get (priv->hadjustment,
+                    "value", &hvalue,
+                    NULL);
+      g_object_get (priv->vadjustment,
+                    "value", &vvalue,
+                    NULL);
+      break;
     case CLUTTER_SCROLL_UP:
     case CLUTTER_SCROLL_DOWN:
       g_object_get (priv->vadjustment,
@@ -712,6 +727,10 @@ st_scroll_view_scroll_event (ClutterActor       *self,
 
   switch (event->direction)
     {
+    case CLUTTER_SCROLL_SMOOTH:
+      st_adjustment_set_value (priv->hadjustment, hvalue + delta_x);
+      st_adjustment_set_value (priv->vadjustment, vvalue + delta_y);
+      break;
     case CLUTTER_SCROLL_UP:
       if (value == lower)
         return FALSE;
