@@ -85,7 +85,7 @@ struct _StTablePrivate
 
 static void st_table_container_iface_init (ClutterContainerIface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (StTable, st_table, ST_TYPE_CONTAINER,
+G_DEFINE_TYPE_WITH_CODE (StTable, st_table, ST_TYPE_WIDGET,
                          G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_CONTAINER,
                                                 st_table_container_iface_init));
 
@@ -99,15 +99,15 @@ st_table_actor_removed (ClutterContainer *container,
                         ClutterActor     *actor)
 {
   StTablePrivate *priv = ST_TABLE (container)->priv;
-  GList *list, *children;
   gint n_rows = 0;
   gint n_cols = 0;
+  ClutterActor *child;
 
   /* Calculate and update the number of rows / columns */
-  children = st_container_get_children_list (ST_CONTAINER (container));
-  for (list = children; list; list = list->next)
+  for (child = clutter_actor_get_first_child (CLUTTER_ACTOR (container));
+       child != NULL;
+       child = clutter_actor_get_next_sibling (child))
     {
-      ClutterActor *child = CLUTTER_ACTOR (list->data);
       StTableChild *meta;
 
       if (child == actor)
@@ -221,11 +221,11 @@ st_table_homogeneous_allocate (ClutterActor          *self,
                                const ClutterActorBox *content_box,
                                gboolean               flags)
 {
-  GList *list, *children;
   gfloat col_width, row_height;
   gint row_spacing, col_spacing;
   StTablePrivate *priv = ST_TABLE (self)->priv;
-  gboolean ltr = st_widget_get_direction (ST_WIDGET (self)) == ST_TEXT_DIRECTION_LTR;
+  gboolean ltr = clutter_actor_get_text_direction (self) == CLUTTER_TEXT_DIRECTION_LTR;
+  ClutterActor *child;
 
   col_spacing = priv->col_spacing;
   row_spacing = priv->row_spacing;
@@ -237,17 +237,14 @@ st_table_homogeneous_allocate (ClutterActor          *self,
                       - (row_spacing * (priv->n_rows - 1)))
                       / priv->n_rows + 0.5);
 
-  children = st_container_get_children_list (ST_CONTAINER (self));
-  for (list = children; list; list = list->next)
+  for (child = clutter_actor_get_first_child (self);
+       child != NULL;
+       child = clutter_actor_get_next_sibling (child))
     {
       gint row, col, row_span, col_span;
       StTableChild *meta;
-      ClutterActor *child;
       ClutterActorBox childbox;
-      StAlign x_align, y_align;
-      gboolean x_fill, y_fill;
-
-      child = CLUTTER_ACTOR (list->data);
+      gdouble x_align_f, y_align_f;
 
       meta = (StTableChild *) clutter_container_get_child_meta (CLUTTER_CONTAINER (self), child);
 
@@ -259,10 +256,9 @@ st_table_homogeneous_allocate (ClutterActor          *self,
       row = meta->row;
       row_span = meta->row_span;
       col_span = meta->col_span;
-      x_align = meta->x_align;
-      y_align = meta->y_align;
-      x_fill = meta->x_fill;
-      y_fill = meta->y_fill;
+
+      _st_get_align_factors (meta->x_align, meta->y_align,
+                             &x_align_f, &y_align_f);
 
       if (ltr)
         {
@@ -278,10 +274,10 @@ st_table_homogeneous_allocate (ClutterActor          *self,
       childbox.y1 = content_box->y1 + (row_height + row_spacing) * row;
       childbox.y2 = childbox.y1 + (row_height * row_span) + (row_spacing * (row_span - 1));
 
-      _st_allocate_fill (ST_WIDGET (self), child, &childbox,
-                         x_align, y_align, x_fill, y_fill);
-
-      clutter_actor_allocate (child, &childbox, flags);
+      clutter_actor_allocate_align_fill (child, &childbox,
+                                         x_align_f, y_align_f,
+                                         meta->x_fill, meta->y_fill,
+                                         flags);
     }
 
 }
@@ -296,7 +292,7 @@ st_table_calculate_col_widths (StTable *table,
   gboolean *is_expand_col;
   gint extra_col_width, n_expanded_cols = 0, expanded_cols = 0;
   gint *pref_widths, *min_widths;
-  GList *list, *children;
+  ClutterActor *child;
 
   g_array_set_size (priv->is_expand_col, 0);
   g_array_set_size (priv->is_expand_col, priv->n_cols);
@@ -310,19 +306,16 @@ st_table_calculate_col_widths (StTable *table,
   g_array_set_size (priv->min_widths, priv->n_cols);
   min_widths = (gint *) priv->min_widths->data;
 
-  children = st_container_get_children_list (ST_CONTAINER (table));
-
-  for (list = children; list; list = list->next)
+  for (child = clutter_actor_get_first_child (CLUTTER_ACTOR (table));
+       child != NULL;
+       child = clutter_actor_get_next_sibling (child))
     {
       gint col;
       gfloat w_min, w_pref;
       gboolean x_expand;
       StTableChild *meta;
-      ClutterActor *child;
       gint col_span;
 
-      child = CLUTTER_ACTOR (list->data);
-
       meta = (StTableChild *) clutter_container_get_child_meta (CLUTTER_CONTAINER (table), child);
 
       if (!meta->allocate_hidden && !CLUTTER_ACTOR_IS_VISIBLE (child))
@@ -398,11 +391,11 @@ st_table_calculate_row_heights (StTable *table,
                                 gint   * col_widths)
 {
   StTablePrivate *priv = ST_TABLE (table)->priv;
-  GList *list, *children;
   gint *is_expand_row, *min_heights, *pref_heights, *row_heights, extra_row_height;
   gint i, total_min_height;
   gint expanded_rows = 0;
   gint n_expanded_rows = 0;
+  ClutterActor *child;
 
   g_array_set_size (priv->row_heights, 0);
   g_array_set_size (priv->row_heights, priv->n_rows);
@@ -420,18 +413,16 @@ st_table_calculate_row_heights (StTable *table,
   g_array_set_size (priv->pref_heights, priv->n_rows);
   pref_heights = (gboolean *) priv->pref_heights->data;
 
-  children = st_container_get_children_list (ST_CONTAINER (table));
-  for (list = children; list; list = list->next)
+  for (child = clutter_actor_get_first_child (CLUTTER_ACTOR (table));
+       child != NULL;
+       child = clutter_actor_get_next_sibling (child))
     {
       gint row, col, cell_width;
       gfloat h_min, h_pref;
       gboolean y_expand;
       StTableChild *meta;
-      ClutterActor *child;
       gint col_span, row_span;
 
-      child = CLUTTER_ACTOR (list->data);
-
       meta = (StTableChild *) clutter_container_get_child_meta (CLUTTER_CONTAINER (table), child);
 
       if (!meta->allocate_hidden && !CLUTTER_ACTOR_IS_VISIBLE (child))
@@ -571,13 +562,13 @@ st_table_preferred_allocate (ClutterActor          *self,
                              const ClutterActorBox *content_box,
                              gboolean               flags)
 {
-  GList *list, *children;
   gint row_spacing, col_spacing;
   gint i;
   gint *col_widths, *row_heights;
   StTable *table;
   StTablePrivate *priv;
   gboolean ltr;
+  ClutterActor *child;
 
   table = ST_TABLE (self);
   priv = ST_TABLE (self)->priv;
@@ -594,21 +585,18 @@ st_table_preferred_allocate (ClutterActor          *self,
                                     (int) (content_box->y2 - content_box->y1),
                                     col_widths);
 
-  ltr = (st_widget_get_direction (ST_WIDGET (self)) == ST_TEXT_DIRECTION_LTR);
+  ltr = (clutter_actor_get_text_direction (self) == CLUTTER_TEXT_DIRECTION_LTR);
 
-  children = st_container_get_children_list (ST_CONTAINER (self));
-  for (list = children; list; list = list->next)
+  for (child = clutter_actor_get_first_child (self);
+       child != NULL;
+       child = clutter_actor_get_next_sibling (child))
     {
       gint row, col, row_span, col_span;
       gint col_width, row_height;
       StTableChild *meta;
-      ClutterActor *child;
       ClutterActorBox childbox;
       gint child_x, child_y;
-      StAlign x_align, y_align;
-      gboolean x_fill, y_fill;
-
-      child = CLUTTER_ACTOR (list->data);
+      gdouble x_align_f, y_align_f;
 
       meta = (StTableChild *) clutter_container_get_child_meta (CLUTTER_CONTAINER (self), child);
 
@@ -620,11 +608,9 @@ st_table_preferred_allocate (ClutterActor          *self,
       row = meta->row;
       row_span = meta->row_span;
       col_span = meta->col_span;
-      x_align = meta->x_align;
-      y_align = meta->y_align;
-      x_fill = meta->x_fill;
-      y_fill = meta->y_fill;
 
+      _st_get_align_factors (meta->x_align, meta->y_align,
+                             &x_align_f, &y_align_f);
 
       /* initialise the width and height */
       col_width = col_widths[col];
@@ -701,10 +687,10 @@ st_table_preferred_allocate (ClutterActor          *self,
       childbox.y2 = (float) MAX (0, child_y + row_height);
 
 
-      _st_allocate_fill (ST_WIDGET (self), child, &childbox,
-                         x_align, y_align, x_fill, y_fill);
-
-      clutter_actor_allocate (child, &childbox, flags);
+      clutter_actor_allocate_align_fill (child, &childbox,
+                                         x_align_f, y_align_f,
+                                         meta->x_fill, meta->y_fill,
+                                         flags);
     }
 }
 
@@ -740,8 +726,8 @@ st_table_get_preferred_width (ClutterActor *self,
   gfloat total_min_width, total_pref_width;
   StTablePrivate *priv = ST_TABLE (self)->priv;
   StThemeNode *theme_node = st_widget_get_theme_node (ST_WIDGET (self));
-  GList *list, *children;
   gint i;
+  ClutterActor *child;
 
   if (priv->n_cols < 1)
     {
@@ -762,15 +748,13 @@ st_table_get_preferred_width (ClutterActor *self,
   pref_widths = (gint *) priv->pref_widths->data;
 
   /* calculate minimum row widths */
-  children = st_container_get_children_list (ST_CONTAINER (self));
-  for (list = children; list; list = list->next)
+  for (child = clutter_actor_get_first_child (self);
+       child != NULL;
+       child = clutter_actor_get_next_sibling (child))
     {
       gint col, col_span;
       gfloat w_min, w_pref;
       StTableChild *meta;
-      ClutterActor *child;
-
-      child = CLUTTER_ACTOR (list->data);
 
       meta = (StTableChild *) clutter_container_get_child_meta (CLUTTER_CONTAINER (self), child);
 
@@ -824,9 +808,9 @@ st_table_get_preferred_height (ClutterActor *self,
   gfloat total_min_height, total_pref_height;
   StTablePrivate *priv = ST_TABLE (self)->priv;
   StThemeNode *theme_node = st_widget_get_theme_node (ST_WIDGET (self));
-  GList *list, *children;
   gint i;
   gint *min_widths;
+  ClutterActor *child;
 
   /* We only support height-for-width allocation. So if we are called
    * width-for-height, calculate heights based on our natural width
@@ -863,15 +847,13 @@ st_table_get_preferred_height (ClutterActor *self,
   pref_heights = (gint *) priv->pref_heights->data;
 
   /* calculate minimum row heights */
-  children = st_container_get_children_list (ST_CONTAINER (self));
-  for (list = children; list; list = list->next)
+  for (child = clutter_actor_get_first_child (self);
+       child != NULL;
+       child = clutter_actor_get_next_sibling (child))
     {
       gint row, col, col_span, cell_width, row_span;
       gfloat min, pref;
       StTableChild *meta;
-      ClutterActor *child;
-
-      child = CLUTTER_ACTOR (list->data);
 
       meta = (StTableChild *) clutter_container_get_child_meta (CLUTTER_CONTAINER (self), child);
 
@@ -915,30 +897,6 @@ st_table_get_preferred_height (ClutterActor *self,
   st_theme_node_adjust_preferred_height (theme_node, min_height_p, natural_height_p);
 }
 
-static void
-st_table_show_all (ClutterActor *table)
-{
-  GList *l, *children;
-
-  children = st_container_get_children_list (ST_CONTAINER (table));
-  for (l = children; l; l = l->next)
-    clutter_actor_show_all (CLUTTER_ACTOR (l->data));
-
-  clutter_actor_show (table);
-}
-
-static void
-st_table_hide_all (ClutterActor *table)
-{
-  GList *l, *children;
-
-  clutter_actor_hide (table);
-
-  children = st_container_get_children_list (ST_CONTAINER (table));
-  for (l = children; l; l = l->next)
-    clutter_actor_hide_all (CLUTTER_ACTOR (l->data));
-}
-
 static void
 st_table_style_changed (StWidget *self)
 {
@@ -978,8 +936,6 @@ st_table_class_init (StTableClass *klass)
   actor_class->allocate = st_table_allocate;
   actor_class->get_preferred_width = st_table_get_preferred_width;
   actor_class->get_preferred_height = st_table_get_preferred_height;
-  actor_class->show_all = st_table_show_all;
-  actor_class->hide_all = st_table_hide_all;
 
   widget_class->style_changed = st_table_style_changed;
 
